@@ -30,49 +30,22 @@ else {
 	$out = *STDOUT
 }
 
-report($out, $stats->get_stats_hash);
+my $config = { };
+$config->{dots} = $ARGV{'--dots'};
+$stats->report($out, $config);
 
 if ( $ARGV{'-o'} ) { close $out; }
 
-# TODO should be somewhere in modules
-sub report{
-	my ($FH, $hash) = @_;
-	my @lines;
-	my $nrecords = $hash->{nrecords};
-	
-	foreach my $tag ( sort keys %{$hash->{tags}} ) {
-		my $tagstat = $hash->{tags}->{$tag};
-		my $is_repeatable = $tagstat->{repeatable} ? '[Y]' : '   ';
-		my $occurence = sprintf("%6.2f",100*$tagstat->{occurence}/$nrecords);
-		push @lines, "$tag     $is_repeatable     $occurence";
-		
-		foreach my $subtag ( sort keys %{ $tagstat->{subtags} } ) {
-			my $subtagstat = $tagstat->{subtags}->{$subtag};
-			my $occurence = sprintf("%6.2f",100.0*$subtagstat->{occurence}/$nrecords);
-			my $is_repeatable = $tagstat->{repeatable} ? '[Y]' : '   ';
-			push @lines, "   $subtag    $is_repeatable     $occurence";
-		}
-		 
-	}
-	
-	if ( $ARGV{'--dots'} ) {		
-		@lines = map { s/\s/./g; $_ } @lines;
-	}
-	
-	unshift @lines, "Tag     Rep.    Occ.,%";
-	unshift @lines, "Statistics for $nrecords records";
-	
-	
-	
-	print $FH join ("\n",@lines), qq{\n\n};
-	
-}
+__END__
 =head1 NAME
 
-marcstats.pl - collect statistics for MARC records
+marcstats.pl - report statistics on MARC records in batch files
 
 =head1 USAGE
 
+Calculate the frequency rate and the repeatability of tags and subtags
+in a number of MARC batch files. 
+
 	marcstats.pl [options] <file>,...
 
 =head1 VERSION
@@ -104,7 +77,7 @@ Replace spaces with dots in the output
 
 =item -o <outfile>
 
-Send output to outfile
+Send output to outfile. By default output is sent to console (STDOUT)
 
 =back
 
